@@ -1,7 +1,7 @@
 `metaMDSdist` <-
-    function (comm, distance = "bray", autotransform = TRUE, noshare = 0.1, 
-              trace = 1, commname, zerodist = "ignore", distfun = vegdist, 
-              ...) 
+    function (comm, distance = "bray", autotransform = TRUE,
+              noshare = TRUE, trace = 1, commname,
+              zerodist = "ignore", distfun = vegdist, ...) 
 {
     ## metaMDSdist should get a raw data matrix, but if it gets a
     ## 'dist' object return that unchanged and quit silently.
