@@ -30,8 +30,10 @@
     res <- list()
     if (label)
         cntrs <- names <- NULL
+    ## Remove NA scores
+    kk <- complete.cases(pts)
     for (is in inds) {
-        gr <- out[groups == is]
+        gr <- out[groups == is & kk]
         if (length(gr) > 2) {
             X <- pts[gr, ]
             W <- w[gr]
